@@ -34,6 +34,7 @@ G_BEGIN_DECLS
 
 typedef struct _TpBaseConnection TpBaseConnection;
 typedef struct _TpBaseConnectionClass TpBaseConnectionClass;
+typedef struct _TpBaseConnectionPrivate TpBaseConnectionPrivate;
 
 /**
  * TpBaseConnectionProc:
@@ -239,7 +240,7 @@ struct _TpBaseConnection {
     gpointer _future3;
     gpointer _future4;
 
-    gpointer priv;
+    TpBaseConnectionPrivate *priv;
 };
 
 GType tp_base_connection_get_type (void);
@@ -262,6 +263,8 @@ void tp_base_connection_add_interfaces (TpBaseConnection *self,
 void tp_base_connection_dbus_request_handles (TpSvcConnection *iface,
     guint handle_type, const gchar **names, DBusGMethodInvocation *context);
 
+void tp_base_connection_register_with_contacts_mixin (TpBaseConnection *self);
+
 /* TYPE MACROS */
 #define TP_TYPE_BASE_CONNECTION \
   (tp_base_connection_get_type ())
